#!/usr/bin/env python
"""
last_supersedes.py - NNTP autoposter.

Copyright 2007 Davide Alberani <da@erlug.linux.it>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
"""


import sys, os, anydbm, getopt


HELP = """last_supersedes.py: show and set the content of a dbm database.
    Show the value of key:
        last_supersedes.py dbFile key

    Show the list of keys:
        last_supersedes.py -l dbFile

    Set the value of the key to keyValue (if keyValue is an empty string
    the key is removed):
        last_supersedes.py -s keyValue dbFile key
"""

try:
    optlist, args = getopt.getopt(sys.argv[1:], 'hls:',
                                    ['help', 'list', 'set='])
except getopt.error, e:
    print HELP
    sys.exit(1)

LIST = False
SET = False
SET_VALUE = None

if len(args) < 1 or len(args) > 2:
    print HELP
    sys.exit(1)

for opt in optlist:
    if opt[0] in ('-h', '--help'):
        print HELP
        sys.exit(0)
    elif opt[0] in ('-l', '--list'):
        LIST = True
    elif opt[0] in ('-s', '--set'):
        SET = True
        SET_VALUE = opt[1]

DB_FILE = args[0]
if not LIST:
    if len(args) != 2:
        print HELP
        sys.exit(1)
    else:
        KEY = args[1]

try:
    db_fp = anydbm.open(DB_FILE, 'c')
    if LIST:
        print 'List of {key: value} in "%s":' % DB_FILE
        for item in db_fp.items():
            print '%s: %s' % item
    elif SET:
        if SET_VALUE:
            print 'Setting key "%s" to "%s"' % (KEY, SET_VALUE)
            db_fp[KEY] = SET_VALUE
        else:
            print 'Removing key "%s"'
            del db_fp[KEY]
    else:
        value = db_fp.get(KEY)
        if value is not None:
            print 'Last Supersedes header for "%s": %s' % (KEY, value)
        else:
            print 'No Supersedes header defined for "%s"' % KEY
    db_fp.close()
except IOError, e:
    print 'Unable to read/write %s: %s' % (DB_FILE, e)
    sys.exit(2)


